IP(1)                   XR32 REFERENCE MANUAL                19/1/2013

COMMAND
        IP -- Display / Change IP routing parameters.

SYNOPSIS
        IP QUIET [level]
        IP ROUTES
        IP ROUTE ADD <host>[/len] <gateway> <port> [mode [metric]]
        IP ROUTE ADDPRIVATE <host/bits> encap <gateway>
        IP ROUTE CMD [0-1]
        IP ROUTE DROP <host> <len>
        IP ROUTE DEFAULT <port> [gateway [mode]]
        IP ROUTE LOAD
        IP ROUTE LOOKUP <host>
        IP TTL [ttl]

AVAILABILITY
        The IP ROUTES command is available to all, providing it
        hasn't been disabled by sysop. The remaining commands are
        sysop-only.

DESCRIPTION
        The IP commands are used to display and alter some of the IP
        parameters, and the contents of the table responsible for
        routing of IP datagrams.

        The arguments are as follows:

        <host>      Target hostname or IP address. IP address is
                    preferred, as it is more efficient. Route default
                    must always be an IP address.

        <len>       No. of bits to be matched (from left) 0-32

        <gateway>   Destination gateway IP address in dotted quad.
 
        <port>      Port number on which to route the datagram.
                    For encapsulated modes (e,i,u), Netrom and reject
                    modes (r and s) this is ignored and should be 0.
                    For IPUDP, this can optionally specify the UDP
                    service number to use (default=94).

        <mode>      How the datagram is routed, as follows..

                      d = Datagram (direct)
                      e = Encap (ip-over-ip protocol 4)
                      i = IPIP  (ip-over-ip protocol 94)
                      n = Netrom (ip-over-netrom)
                      r = Reject
                      s = Silent discard
                      u = IPUDP  (ip-over-UDP) 
                      v = Virtual circuit (ip-over-ax25)
                      w = Winsock

                    The usual mode is "datagram". However, on less
                    than perfect RF links, better performance can be
                    obtained by using Virtual Circuit mode.  Netrom
                    mode is inefficient, but can "tunnel" datagrams
                    across non-ip parts of the network.
                    Encap, IPIP and IPUDP are used for tunneling
                    amateur IP across the public internet.
                    Reject and Silent discard are used to suppress
                    bouncing and looping.
                    Winsock mode is a dummy mode. It tells XR32 to use
                    Windows' IP stack for anything matching the entry,
                    but see Caveats below.

OPTIONS
        The QUIET subcommand is used to display or set XR32's
        "stealth" level, i.e. how it responds to ICMP echo requests
        and TCP port probes. If the level is zero, XR32 behaves
        normally. If a non-zero argument is supplied, XR32 becomes
        stealthy. The stealth level is specified by adding the
        following values:

            1   Suppress ICMP echo replies.
            2   Suppress Protocol unreachable
            4   Suppress TCP refusals
            8   Suppress all ICMP errors
        
        ROUTE CMD is used to allow / disallow the IP ROUTES and
        IPR[outes] commands from being used by non-sysops. On amateur
        networks however, it is considered bad practice to hide IP
        routing.

        The ROUTE DEFAULT subcommand sets up a default route which is
        used when no other route is found.  If no gateway is
        specified, the target will be assumed to be a direct
        neighbour.  If not specified, the mode defaults to datagram.

        The ROUTE ADD subcommand adds an entry to the routing table.
        The first argument is the target host IP address, with optional 
        mask. e.g. 44.131.90.1/32 means "match all 32 bits", whereas 
        44.131.90.0/24 means "match the most significant 24 bits", and 
        would route all 256 addresses from 44.131.90.0 to 
        44.131.90.255.
        The second argument is the "gateway" address, i.e. the address
        of the system which can handle the datagram.  
        The third argument is the port to route the datagram on, and 
        the last argument is the mode (see above).
 
        The ROUTE ADDPRIVATE subcommand is the same as ROUTE ADD,
        except that it marks the route "private", hiding it from
        non-sysops. The regular form has the same syntax as ROUTE ADD
        and can accept any mode, whereas the shortened form is
        provided for backward compatibility with "encap.txt", and can
        only accept mode "encap".

        The ROUTE DROP subcommand removes an entry from the table.
        Both the target host and the mask must match.

        The ROUTE LOAD subcommand clears the existing IP parameters
        and tables, and reloads them from IPROUTE.SYS.

        The ROUTE LOOKUP subcommand displays the gateway and port
        which XR32 will use to reach a given destination.

        The TTL subcommand specifies the default "Time To Live" for
        datagrams originating at this host.

EXAMPLES
        IP ROUTE DEFAULT 3 44.131.90.6 v
        IP ROUTE ADD 44.131.95.0/24 44.131.95.240 9 d
        IP ROUTE DROP 44.131.97.1 32
        IP ROUTE LOOKUP bbc.co.uk

FILES
        The IP commands may be used in IPROUTE.SYS and BOOTCMDS.SYS
        but the only ones that have any meaning in those locations
        are IP ROUTE ADD, IP ROUTE DEFAULT, IP TTL and IP QUIET. It
        is usual to define IP routing in IPROUTE.SYS.

        When XR32 boots, it first reads IPROUTE.SYS, then ENCAP.TXT,
        then finally BOOTCMDS.SYS.

CAVEATS
        Mode "w" should be used with caution. It means "Use Windows
        TCP/IP services to reach this destination", and is intended
        only as a last resort, e.g. when the NdisXpkt driver is not
        being used.

        For "security reasons" Windows does not allow applications
        to route raw IP traffic through it's stack. It actively
        blocks IP protocol 4 (IPEncap), and puts severe restrictions
        on TCP and UDP traffic.

        Windows allows XR32 to originate and terminate TCP, UDP,
        IPIP, ICMP and AXIP, but not to *route* those protocols.
        Therefore you may Telnet and Ping from XR32, but you are not
        allowed to route 3rd party traffic, e.g. from RF to Internet.

NOTES
        The IP routing table is necessary only for IP, and does not 
        take any part in normal ax25 and Netrom activities.  See the 
        full manual for details on how to set up the IP system.

        Please do not over-use ADDPRIVATE, as it hinders the
        diagnosis of networking problems, and many consider it to
        be contrary to the spitit of Ham Radio.

SEE ALSO
        IP-PRIMER -- IP Addressing / Routing Primer.
        IPROUTE(1) -- Display IP Routes

IP(1)                        END OF DOCUMENT
