ROUTES(1)               XR32 REFERENCE MANUAL                19/1/2013

COMMAND
        ROUTES -- Add, Drop and List Neighbour Routes.  

SYNOPSIS
        R[outes] [* | Q | X | Y | Z]
        R[OUTES] ADD  <call> <port> <qual> [!] [V digis] [opts]
        R[OUTES] DROP <call> <port>

AVAILABILITY
        The ROUTES command is available to all users, but the ADD
        and DROP options are sysop-only.

DESCRIPTION
        The ROUTES command, which may be abbreviated to "R", lists the 
        immediately adjacent NetRom nodes, i.e. those who can be heard 
        directly, providing those nodes are making NetRom nodes 
        broadcasts.

        For each neighbour node the display shows the port number, the 
        neighbour's callsign, the route quality, and the number of 
        nodes accessible through that neighbour.  A chevron (>) in the 
        left-most column indicates a route which is in use, and an 
        exclamation mark (!) in the right-most column indicates that 
        the data has been "locked in" by the sysop. For example:

        G8PZT:KIDDER} Routes:
        Port Callsign  Qty Nod
        >  5 G4FPV     150  70!
        >  7 GB7PZT    250   1!
        >  8 GB7WV-12  100  32!
        >  9 GB7GH     150 104!
          10 GB7CL     150   1!
        > 11 GB7IPT-7  150   3!
          12 G1LOA-10  150   2!

OPTIONS
        If no arguments are supplied, the output is as above.

        If any argument is supplied, it will give additional 
        information mainly of interest to sysops.

        R *  - Display additional detail (see below)
        R Q  - Display calculated qualities
        R X  - Display details of retry rates
        R Y  - Display trip times, and settings for temporal metrics
        R Z  - Display Connection percentage & data throughputs.

DETAILS
        "R *" displays the current MAXFRAME, FRACK and PACLEN settings, 
        the number of information frames sent, the number of 
        information frames re-sent, the retry rate, which is the ratio 
        of the two preceeding figures (or * if both are zero), and the 
        time a nodes broadcast was last heard from the neighbour.

        "R Q" displays the calculated route qualities. These are based
        on measurements of actual link performance, and are independent
        of qualities specified by sysops. They are intended as a guide
        to help sysops make an informed choice for link quality. The
        values shown are the smoothed calculated quality, the minimum
        and maximum calculated qualities, and the standard deviation
        of the mean.

        "R X" displays extended information about the retry rates to
        each neighbour. The values shown are the number of frames sent
        and re-sent, and the long-term average retry rate which is the
        ratio of the two preceeding figures (or * if both are zero).
        Also shown is a "running average" retry rate, which is more
        responsive to short-term variations (e.g. due to QRM on a link),
        the maximum value attained by that average, and the date/time
        when that maximum was attained. This often reveals links with
        low mean retry rates that have some surprising short term highs.

        "R Y" displays information and settings concerned with temporal
        metrics, i.e those based on trip time. The displayed values are
        as follows:

           Tdr    - Nodes learned from neighbour via temporal metrics.
           Stt    - Smoothed Trip Time to the neighbour.
           Flg    - Flags, the sum of the following:

                      1 - Route locked in by sysop.
                      2 - Neighbour is INP3 compatible.
                      4 - Neighbour responds to our L3RTT probes.
                      8 - Neighbour is XRouter / XR32.
                     16 - Automatic route quality enabled.

           MaxTT  - Max Trip Time allowed via this route.
           MaxHop - Max Hop count allowed via this route.

        The final figure is the neighbour's MaxTT setting, which may
        differ from ours.

        "R Z" displays information about connection percentage and
        data throughputs:

           Con%  - Percentage of time that link has been connected.
           Peak  - Max throughput including resends
           Best  - Best mean throughput achieved, excluding resends
           Mean  - Running mean throughput in bytes/sec.
           Load  - Long term average throughput (TX+RX) in bytes/sec.
           Last  - Last date/time that any traffic used this route.


        "ROUTE ADD" adds a new route or modifies an existing one. The
        arguments are as follows:

               <call> is the callsign of the neighbour node.

               <port> is the radio port via which the neighbour is
                      reached.

               <qual> is the netrom "quality" to use for that route.
                      A quality between 256 and 511 will instruct
                      XR32 to use "automatic" quality, with a starting
                      value of (qual-256). 

               [!] locks the entry to prevent it being overridden by
                   learned information.

               [V digis] specifies a digipeated route, where "digis"
                         is a string of digipeater calls seperated by
                         commas, i.e. in the form "DIGI,DIGI,DIGI".

               [opts] are optional maxframe, frack, paclen, maxtt and
                      maxhops values to override the port defaults.
                      The format is:
                      [maxframe [frack [paclen [maxtt [maxhops]]]]],
                      i.e. in order to specify maxtt you must also
                      specify maxframe, frack and paclen  Use zero in
                      any field you don't wish to change.

        "ROUTE DROP <call> <port>" deletes an existing route.

EXAMPLES
         route add g8pzt 5 100
         route add g6yak 2 100 ! V G8EPR,G8NTU 5 7000
         route add g8klm 3 150 ! 0 0 245 2000 3
         route drop mb7uyl 14

SEE ALSO
        AUTOQUAL(9)  -- Automatic Route Quality
        NODES(1)     -- Display Nodes Tables.
        PERMLINKS(9) -- Permanent NetRom Neighbour Links.

ROUTES(1)                         END OF DOCUMENT
